==> payara-embedded-all-4.1.1.164-sources.jar: org/glassfish/flashlight/impl/MonitoringRuntimeDataRegistryImpl.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2009-2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package org.glassfish.flashlight.impl;

import org.glassfish.flashlight.*;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import org.glassfish.flashlight.datatree.TreeNode;

import org.jvnet.hk2.annotations.Service;
import javax.inject.Singleton;

/**
 * @author Harpreet Singh
 */

@Service
@Singleton
public class MonitoringRuntimeDataRegistryImpl 
        implements MonitoringRuntimeDataRegistry {
    
    
    protected Map<String, TreeNode> children =
            new ConcurrentHashMap<String, TreeNode>();


    public MonitoringRuntimeDataRegistryImpl (){      
    }
    
    public void add(String name, TreeNode node) {
        if (name != null )
             children.put(name, node);
        else {
            throw new RuntimeException ("MonitoringRuntimeDataRegistry does not take null keys");
        }
    }

    public void remove(String name) {
        if (name != null)
            children.remove(name);
    }

    public TreeNode get (String name) {
        TreeNode node = (name != null)? children.get(name): null;
        return node;
    }
}

==> payara-embedded-all-5.193.1-sources.jar: org/glassfish/flashlight/impl/MonitoringRuntimeDataRegistryImpl.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2009-2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
// Portions Copyright [2018] Payara Foundation and/or affiliates

package org.glassfish.flashlight.impl;

import org.glassfish.flashlight.*;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import org.glassfish.flashlight.datatree.TreeNode;

import org.jvnet.hk2.annotations.Service;
import javax.inject.Singleton;

/**
 * @author Harpreet Singh
 */
@Service
@Singleton
public class MonitoringRuntimeDataRegistryImpl implements MonitoringRuntimeDataRegistry {
    
    
    protected Map<String, TreeNode> children = new ConcurrentHashMap<String, TreeNode>();


    public MonitoringRuntimeDataRegistryImpl (){      
    }
    
    @Override
    public void add(String name, TreeNode node) {
        if (name != null ) {
             children.put(name, node);
        } else {
            throw new RuntimeException ("MonitoringRuntimeDataRegistry does not take null keys");
        }
    }

    public void remove(String name) {
        if (name != null)
            children.remove(name);
    }

    @Override
    public TreeNode get (String name) {
        TreeNode node = (name != null)? children.get(name): null;
        return node;
    }
}
